pub struct GetWrappingKeyRequest {
pub mount: String,
}Expand description
Get wrapping key to be able to import a key
This endpoint is used to retrieve the wrapping key to use for importing keys. The returned key will be a 4096-bit RSA public key.
- Path: {self.mount}/transit/wrapping_key
- Method: GET
- Response: GetWrappingKeyResponse
- Reference: https://developer.hashicorp.com/vault/api-docs/secret/transit#get-wrapping-key
Fields
mount: StringImplementations
Sourceimpl GetWrappingKeyRequest
impl GetWrappingKeyRequest
pub fn builder() -> GetWrappingKeyRequestBuilder